package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.XysImgMapper;
import com.ruoyi.system.domain.XysImg;
import com.ruoyi.system.service.IXysImgService;

/**
 * 图片管理Service业务层处理
 * 
 * @author libao
 * @date 2024-07-08
 */
@Service
public class XysImgServiceImpl implements IXysImgService 
{
    @Autowired
    private XysImgMapper xysImgMapper;

    /**
     * 查询图片管理
     * 
     * @param id 图片管理主键
     * @return 图片管理
     */
    @Override
    public XysImg selectXysImgById(Long id)
    {
        return xysImgMapper.selectXysImgById(id);
    }

    /**
     * 查询图片管理列表
     * 
     * @param xysImg 图片管理
     * @return 图片管理
     */
    @Override
    public List<XysImg> selectXysImgList(XysImg xysImg)
    {
        return xysImgMapper.selectXysImgList(xysImg);
    }

    /**
     * 新增图片管理
     * 
     * @param xysImg 图片管理
     * @return 结果
     */
    @Override
    public int insertXysImg(XysImg xysImg)
    {
        xysImg.setCreateTime(DateUtils.getNowDate());
        return xysImgMapper.insertXysImg(xysImg);
    }

    /**
     * 修改图片管理
     * 
     * @param xysImg 图片管理
     * @return 结果
     */
    @Override
    public int updateXysImg(XysImg xysImg)
    {
        xysImg.setUpdateTime(DateUtils.getNowDate());
        return xysImgMapper.updateXysImg(xysImg);
    }

    /**
     * 批量删除图片管理
     * 
     * @param ids 需要删除的图片管理主键
     * @return 结果
     */
    @Override
    public int deleteXysImgByIds(Long[] ids)
    {
        return xysImgMapper.deleteXysImgByIds(ids);
    }

    /**
     * 删除图片管理信息
     * 
     * @param id 图片管理主键
     * @return 结果
     */
    @Override
    public int deleteXysImgById(Long id)
    {
        return xysImgMapper.deleteXysImgById(id);
    }
}
