package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.XysImg;
import com.ruoyi.system.service.IXysImgService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 图片管理Controller
 *
 * @author libao
 * @date 2024-07-08
 */
@RestController
@RequestMapping("/system/img")
public class XysImgController extends BaseController
{
    @Autowired
    private IXysImgService xysImgService;

    /**
     * 查询图片管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:img:list')")
    @GetMapping("/list")
    public TableDataInfo list(XysImg xysImg)
    {
        startPage();
        List<XysImg> list = xysImgService.selectXysImgList(xysImg);
        return getDataTable(list);
    }

    /**
     * 导出图片管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:img:export')")
    @Log(title = "图片管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, XysImg xysImg)
    {
        List<XysImg> list = xysImgService.selectXysImgList(xysImg);
        ExcelUtil<XysImg> util = new ExcelUtil<XysImg>(XysImg.class);
        util.exportExcel(response, list, "图片管理数据");
    }

    /**
     * 获取图片管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:img:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(xysImgService.selectXysImgById(id));
    }

    /**
     * 新增图片管理
     */
    @PreAuthorize("@ss.hasPermi('system:img:add')")
    @Log(title = "图片管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody XysImg xysImg)
    {
        return toAjax(xysImgService.insertXysImg(xysImg));
    }

    /**
     * 修改图片管理
     */
    @PreAuthorize("@ss.hasPermi('system:img:edit')")
    @Log(title = "图片管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody XysImg xysImg)
    {
        return toAjax(xysImgService.updateXysImg(xysImg));
    }

    /**
     * 删除图片管理
     */
    @PreAuthorize("@ss.hasPermi('system:img:remove')")
    @Log(title = "图片管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(xysImgService.deleteXysImgByIds(ids));
    }
}
